RethPayloadStatus

Struct RethPayloadStatus 

#[non_exhaustive]
pub struct RethPayloadStatus { pub status: PayloadStatus, pub latency_us: u64, pub persistence_wait_us: Option<u64>, pub execution_cache_wait_us: Option<u64>, pub sparse_trie_wait_us: Option<u64>, }
Extended payload status returned by reth_newPayload.

Wraps the standard PayloadStatus with server-side timing information.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
status: PayloadStatus

The standard payload status.

latency_us: u64

Total execution latency in microseconds.

persistence_wait_us: Option<u64>

Time spent waiting for persistence in microseconds, if applicable.

execution_cache_wait_us: Option<u64>

Time spent waiting for the execution cache lock in microseconds, if applicable.

sparse_trie_wait_us: Option<u64>

Time spent waiting for the sparse trie lock in microseconds, if applicable.

Implementations

Source

impl RethPayloadStatus

pub const fn new(status: PayloadStatus, latency_us: u64) -> Self

Creates a new RethPayloadStatus with the given status and latency.

pub const fn with_persistence_wait_us(self, us: u64) -> Self

Sets the persistence wait time.

pub const fn with_execution_cache_wait_us(self, us: u64) -> Self

Sets the execution cache wait time.

pub const fn with_sparse_trie_wait_us(self, us: u64) -> Self

Sets the sparse trie wait time.