BalanceChangesInBlock

Type Alias BalanceChangesInBlock 

pub type BalanceChangesInBlock = HashMap<Address, U256>;
Response type for reth_getBalanceChangesInBlock.

Maps addresses to their updated balances after block execution.

Aliased Type

pub struct BalanceChangesInBlock { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 48 bytes