#[non_exhaustive]pub struct RethPayloadStatus {
pub status: PayloadStatus,
pub latency_us: u64,
pub persistence_wait_us: Option<u64>,
pub execution_cache_wait_us: Option<u64>,
pub sparse_trie_wait_us: Option<u64>,
}Expand description
Extended payload status returned by reth_newPayload.
Wraps the standard PayloadStatus with server-side timing information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: PayloadStatusThe standard payload status.
latency_us: u64Total execution latency in microseconds.
persistence_wait_us: Option<u64>Time spent waiting for persistence in microseconds, if applicable.
execution_cache_wait_us: Option<u64>Time spent waiting for the execution cache lock in microseconds, if applicable.
sparse_trie_wait_us: Option<u64>Time spent waiting for the sparse trie lock in microseconds, if applicable.
Implementations
Sourceimpl RethPayloadStatus
impl RethPayloadStatus
Sourcepub const fn new(status: PayloadStatus, latency_us: u64) -> Self
pub const fn new(status: PayloadStatus, latency_us: u64) -> Self
Creates a new RethPayloadStatus with the given status and latency.
Sourcepub const fn with_persistence_wait_us(self, us: u64) -> Self
pub const fn with_persistence_wait_us(self, us: u64) -> Self
Sets the persistence wait time.
Sourcepub const fn with_execution_cache_wait_us(self, us: u64) -> Self
pub const fn with_execution_cache_wait_us(self, us: u64) -> Self
Sets the execution cache wait time.
Sourcepub const fn with_sparse_trie_wait_us(self, us: u64) -> Self
pub const fn with_sparse_trie_wait_us(self, us: u64) -> Self
Sets the sparse trie wait time.