pub type RethBigBlockData<ExecutionData> = BigBlockData<ExecutionData>;Expand description
Compatibility alias for BigBlockData.
Aliased Type
pub struct RethBigBlockData<ExecutionData> {
pub env_switches: Vec<ExecutionData>,
pub prior_block_hashes: Vec<(u64, FixedBytes<32>)>,
pub block_number: u64,
pub merged_block_access_list: Option<Bytes>,
}Fields
env_switches: Vec<ExecutionData>Execution data for each constituent environment in the big block.
prior_block_hashes: Vec<(u64, FixedBytes<32>)>Block numbers and hashes preceding the big block.
block_number: u64Number of the big block.
merged_block_access_list: Option<Bytes>Optional merged block access list.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 88 bytes